@@ -21,6 +21,7 @@
 
 #include <DB/FileName.h>
 #include "Settings/SettingsData.h"
+#include <Utilities/Util.h>
 
 #include <QFile>
 #include <QImage>
@@ -39,14 +40,20 @@ bool RAWImageDecoder::_decode( QImage *img, const DB::FileName& imageFile, QSize
     Q_UNUSED( dim );
 
 #ifdef HAVE_KDCRAW
-    if ( !KDcrawIface::KDcraw::loadRawPreview( *img, imageFile.absolute() ) )
+    QByteArray previewData;
+    if ( !KDcrawIface::KDcraw::loadEmbeddedPreview( previewData, imageFile.absolute() ) )
+        return false;
+
+    // Faster than allowing loadRawPreview to do the decode itself
+    if ( ! Utilities::loadJPEG(img, previewData, fullSize, dim ) )
         return false;
 
     // FIXME: The preview data for Canon's image is always returned in its non-rotated form by libkdcraw, ie. KPA should do the rotation.
     // FIXME: This will happen later on.
     if ( Settings::SettingsData::instance()->useRawThumbnail() &&
-         img->width() >= Settings::SettingsData::instance()->useRawThumbnailSize().width() &&
-         img->height() >= Settings::SettingsData::instance()->useRawThumbnailSize().height() )
+         ( ( dim > 0 && img->width() >= dim && img->height() >= dim ) ||
+           ( img->width() >= Settings::SettingsData::instance()->useRawThumbnailSize().width() &&
+             img->height() >= Settings::SettingsData::instance()->useRawThumbnailSize().height() ) ) )
         return true;
 
     KDcrawIface::DcrawInfoContainer metadata;
@@ -132,7 +139,13 @@ void RAWImageDecoder::_initializeExtensionLists( QStringList& rawExtensions, QSt
                            << QString::fromLatin1("html")
                            << QString::fromLatin1("HTML")
                            << QString::fromLatin1("htm")
-                           << QString::fromLatin1("HTM");
+                           << QString::fromLatin1("HTM")
+                           << QString::fromLatin1("pp3") // RawTherapee Sidecar files
+                           << QString::fromLatin1("PP3")
+                           << QString::fromLatin1("xmp") // Other sidecars
+                           << QString::fromLatin1("XMP")
+                           << QString::fromLatin1("pto") // Hugin sidecars
+                           << QString::fromLatin1("PTO");
 
         QChar dot( QChar::fromLatin1('.') );
         for ( QStringList::iterator it = _rawExtensions.begin(); it != _rawExtensions.end(); ++it )
