@@ -46,7 +46,7 @@ using namespace MainWindow;
 AutoStackImages::AutoStackImages( QWidget* parent, const DB::FileNameList& list )
     :QDialog( parent ), m_list( list )
 {
-    setWindowTitle( i18n("Automatically Stack Images" ) );
+    setWindowTitle( i18nc("@title:window", "Automatically Stack Images" ) );
 
     QWidget* top = new QWidget;
     QVBoxLayout* lay1 = new QVBoxLayout( top );
