@@ -20,14 +20,15 @@
 #define KPHOTOALBUM_PLUGININTERFACE_H
 
 #include <config-kpa-kipi.h>
-#include <libkipi/interface.h>
+
 #include <QList>
 #include <QVariant>
-#include <libkipi/imagecollection.h>
-#include <libkipi/imageinfo.h>
-#include <libkipi/imagecollectionselector.h>
-#include <kurl.h>
-#include <kdemacros.h>
+#include <QUrl>
+
+#include <KIPI/ImageCollection>
+#include <KIPI/ImageCollectionSelector>
+#include <KIPI/ImageInfo>
+#include <KIPI/Interface>
 
 class QPixmap;
 class KFileItem;
@@ -39,27 +40,37 @@ class BreadcrumbList;
 namespace Plugins
 {
 
-class KDE_EXPORT Interface :public KIPI::Interface
+class Interface :public KIPI::Interface
 {
     Q_OBJECT
 
 public:
-    explicit Interface( QObject *parent, const char *name=nullptr);
+    explicit Interface( QObject *parent, QString name=QString());
+
     virtual KIPI::ImageCollection currentAlbum() override;
     virtual KIPI::ImageCollection currentSelection() override;
     virtual QList<KIPI::ImageCollection> allAlbums() override;
-    virtual KIPI::ImageInfo info( const KUrl& ) override;
-    virtual bool addImage( const KUrl&, QString& errmsg ) override;
-    virtual void delImage( const KUrl& ) override;
-    virtual void refreshImages( const KUrl::List& urls ) override;
-    virtual int features() const override;
-    virtual QAbstractItemModel * getTagTree() const override;
-    virtual QVariant hostSetting( const QString& settingName ) override;
+
+    virtual KIPI::ImageInfo info( const QUrl& ) override;
+    virtual bool addImage( const QUrl&, QString& errmsg ) override;
+    virtual void delImage( const QUrl& ) override;
+    virtual void refreshImages( const QList<QUrl>& urls ) override;
+
+    virtual void thumbnail(const QUrl &url, int size) override;
+    virtual void thumbnails(const QList<QUrl> &list, int size) override;
+
     virtual KIPI::ImageCollectionSelector* imageCollectionSelector(QWidget *parent) override;
     virtual KIPI::UploadWidget* uploadWidget(QWidget *parent) override;
+    virtual QAbstractItemModel * getTagTree() const override;
 
-    virtual void thumbnail(const KUrl &url, int size) override;
-    virtual void thumbnails(const KUrl::List &list, int size) override;
+    // these two methods are only here because of a libkipi api error
+    // either remove them when they are no longer pure virtual in KIPI::Interface,
+    // or implement them and update features() accordingly:
+    // FIXME: this can be safely removed if/when libkipi 5.1.0 is no longer supported
+    virtual KIPI::FileReadWriteLock* createReadWriteLock(const QUrl&) const override;
+    virtual KIPI::MetadataProcessor* createMetadataProcessor() const override;
+
+    virtual int features() const override;
 
 public slots:
     void slotSelectionChanged( bool );
@@ -70,7 +81,7 @@ private slots:
     void failedKDEPreview(const KFileItem& item);
 
 signals:
-    void imagesChanged( const KUrl::List& );
+    void imagesChanged( const QList<QUrl>& );
 };
 
 }
