@@ -19,6 +19,7 @@
 #define UNTAGGEDGROUPBOX_H
 #include <QGroupBox>
 class QComboBox;
+class QCheckBox;
 
 namespace Settings
 {
@@ -31,6 +32,8 @@ public:
     explicit UntaggedGroupBox( QWidget* parent = 0);
     void loadSettings( Settings::SettingsData* opt );
     void saveSettings( Settings::SettingsData* opt );
+    void categoryDeleted(QString categoryName);
+    void categoryRenamed(QString oldCategoryName, QString newCategoryName);
 
 private slots:
     void populateCategoryComboBox();
@@ -39,6 +42,7 @@ private slots:
 private:
     QComboBox* m_category;
     QComboBox* m_tag;
+    QCheckBox* m_showUntaggedImagesTag;
 };
 
 }
