@@ -55,7 +55,7 @@ void ThumbnailView::ThumbnailDND::contentsDragMoveEvent( QDragMoveEvent* event )
 
     if ( ( event->pos().y() < 10 ) )
         widget()->scrollTo( widget()->indexUnderCursor(), QAbstractItemView::PositionAtCenter );
-    if ( ( event->pos().y() > widget()->viewport()->visibleRegion().rects().first().height() - 10 ) )
+    if ( ( event->pos().y() > widget()->viewport()->visibleRegion().cbegin()->height() - 10 ) )
         widget()->scrollTo( widget()->indexUnderCursor(), QAbstractItemView::PositionAtCenter );
     bool left = ( event->pos().x() - rect.x() < rect.width()/2 );
     if ( left ) {
