@@ -52,6 +52,8 @@ bool isRAW( const DB::FileName& fileName );
 QString locateDataFile(const QString& fileName);
 QString readFile( const QString& fileName );
 bool loadJPEG(QImage *img, const DB::FileName& imageFile, QSize* fullSize, int dim=-1);
+bool loadJPEG(QImage *img, const DB::FileName& imageFile, QSize* fullSize, int dim=-1, char *membuf=NULL, size_t membufSize=0);
+bool loadJPEG(QImage *img, const QByteArray& data, QSize* fullSize, int dim=-1);
 bool isJPEG( const DB::FileName& fileName );
 
 QString stripEndingForwardSlash( const QString& fileName );
