@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2015 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -501,11 +501,22 @@ XMLDB::ReaderPtr XMLDB::FileReader::readConfigFile( const QString& configFile )
     return reader;
 }
 
+/**
+ * @brief Unescape a string used as an XML attribute name.
+ *
+ * @see XMLDB::FileWriter::escape
+ *
+ * @param str the string to be unescaped
+ * @return the unescaped string
+ */
 QString XMLDB::FileReader::unescape( const QString& str )
 {
-    static QHash<QString,QString> cache;
-    if ( cache.contains(str) )
-        return cache[str];
+    static bool hashUsesCompressedFormat = useCompressedFileFormat();
+    static QHash<QString,QString> s_cache;
+    if (hashUsesCompressedFormat != useCompressedFileFormat())
+        s_cache.clear();
+    if ( s_cache.contains(str) )
+        return s_cache[str];
 
     QString tmp( str );
     // Matches encoded characters in attribute names
@@ -523,7 +534,7 @@ QString XMLDB::FileReader::unescape( const QString& str )
     } else
         tmp.replace( QString::fromLatin1( "_" ), QString::fromLatin1( " " ) );
 
-    cache.insert(str,tmp);
+    s_cache.insert(str,tmp);
     return tmp;
 }
 
