@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2014 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -489,14 +489,23 @@ bool XMLDB::FileWriter::shouldSaveCategory( const QString& categoryName ) const
 }
 
 /**
- * Escape problematic characters in a string that forms an XML attribute name.
+ * @brief Escape problematic characters in a string that forms an XML attribute name.
+ *
  * N.B.: Attribute values do not need to be escaped!
+ * @see XMLDB::FileReader::unescape
+ *
+ * @param str the string to be escaped
+ * @return the escaped string
  */
 QString XMLDB::FileWriter::escape( const QString& str )
 {
-    static QHash<QString,QString> cache;
-    if ( cache.contains(str) )
-        return cache[str];
+    static bool hashUsesCompressedFormat = useCompressedFileFormat();
+    static QHash<QString,QString> s_cache;
+    if (hashUsesCompressedFormat != useCompressedFileFormat())
+        s_cache.clear();
+
+    if ( s_cache.contains(str) )
+        return s_cache[str];
 
     QString tmp( str );
     // Regex to match characters that are not allowed to start XML attribute names
@@ -514,7 +523,7 @@ QString XMLDB::FileWriter::escape( const QString& str )
         }
     } else
         tmp.replace( QString::fromLatin1( " " ), QString::fromLatin1( "_" ) );
-    cache.insert(str,tmp);
+    s_cache.insert(str,tmp);
     return tmp;
 }
 
